qbm package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   qbm.models
   qbm.simulation
   qbm.utils

Module contents
---------------

.. automodule:: qbm
   :members:
   :undoc-members:
   :show-inheritance:
